BUILD = 'Build'
CANCEL = 'Cancel'
CLOSE = 'Close'
CODE = 'Code'
COMPARE = 'Compare'
CONFIG = 'Config'
COPY = 'Copy'
DELETE = 'Delete'
DELETE_THESE_ITEMS = 'Are you sure you want to delete these item(s)?'
DIFF = 'Diff'
DONE = 'Done'
EDIT = 'Edit'
EVENT = 'Event'
EXIT = 'Exit'
HELP = 'Help'
NEW = 'New'
NEXT = 'Next'
NO = 'No'
NO_SUCH_FILE = 'no such file or directory'
OK = 'OK'
OPEN = 'Open'
PAUSE = 'Pause'
PREFERENCES = 'Preferences'
PREVIOUS = 'Prev'
PROCESS = 'Process'
QUIT = 'Quit'
REDO = 'Redo'
REFRESH = 'Refresh'
REPORT = 'Report'
RENAME = 'Rename'
RESET = 'Reset'
RUN = 'Run'
SAVE = 'Save'
SAVE_PDF = 'Save as PDF'
SEND = 'Send'
START = 'Start'
UPDATE = 'Update'
UPGRADE = 'Upgrade'
USE = 'Use'
WINDOWS = 'Windows'
YES = 'Yes'
